==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/cs.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Průzkum používání",
    "Last report sent on: {on}" : "Poslední hlášení odesláno: {on}",
    "An error occurred while sending your report." : "Při odesílání hlášení došlo k chybě.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, zda povolená)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databázové prostředí <em>(typ, verze, velikost databáze)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informace o šifrování <em>(je to zapnuto?, jaký je výchozí modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Počet sdílení <em>(podle typu a nastavení oprávnění)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP prostředí <em>(verze, limit paměti, max. doba vykonávání, max. velikost souboru)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti o instanci serveru <em>(verze, použití memcache, stav blokování /náhledů/avatarů)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet souborů, uživatelů, jednotlivých úložišť, komentářů a štítků)</em>",
    "Help improve Nextcloud" : "Pomozte zlepšit Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcete nám pomoci zlepšit aplikaci Nextcloud poskytnutím některých anonymních údajů o vašem nastavení a použití? Můžete vše znovu kdykoli vypnout v nastavení správy.",
    "Not now" : "Teď ne",
    "Send usage" : "Odeslat přehled",
    "Never" : "Nikdy",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Odeslat anonymizovaná data vývojářům Nextcloud a pomoci ho tak zlepšovat.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby na jejich základě mohli Nextcloud dále vylepšovat.\n       máte vždy plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení zakázáno a pokud se je rozhodnete zapnout, bude nejdříve anonymizováno a budete mít možnost vybrat, jaké věci sdílet. Po obdržení zprávy se předchozí odebere. Nahraje se čistý přehled a odstraní se všechna data aktuálně uložená na serveru.",
    "Send new report now" : "Odeslat nový přehled hned",
    "Send usage survey monthly" : "Odeslat přehled o používání měsíčně",
    "Data to send" : "Data k odeslání",
    "Last report sent on: %s" : "Poslední hlášení odesláno: %s",
    "Last report" : "Poslední přehled",
    "Sent on: {on}" : "Odesláno: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet: souborů, uživatelů, uložišť podle typu, komentářů a značek)</em>",
    "Sent on: %s" : "Odeslán: %s"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/cs.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Poslední hlášení odesláno: {on}",
    "An error occurred while sending your report." : "Při odesílání hlášení došlo k chybě.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Seznam aplikací <em>(pro každou aplikaci: název, verze, zda povolená)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databázové prostředí <em>(typ, verze, velikost databáze)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informace o šifrování <em>(je to zapnuto?, jaký je výchozí modul)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Počet sdílení <em>(podle typu a nastavení oprávnění)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP prostředí <em>(verze, limit paměti, max. doba vykonávání, max. velikost souboru)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Podrobnosti o instanci serveru <em>(verze, použití memcache, stav blokování /náhledů/avatarů)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistika <em>(počet souborů, uživatelů, jednotlivých úložišť, komentářů a štítků)</em>",
    "Usage survey" : "Průzkum používání",
    "Help improve Nextcloud" : "Pomozte zlepšit Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcete nám pomoci zlepšit aplikaci Nextcloud poskytnutím některých anonymních údajů o vašem nastavení a použití? Můžete vše znovu kdykoli vypnout v nastavení správy.",
    "Not now" : "Teď ne",
    "Send usage" : "Odeslat přehled",
    "Never" : "Nikdy",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Odeslat anonymizovaná data vývojářům Nextcloud a pomoci ho tak zlepšovat.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby na jejich základě mohli Nextcloud dále vylepšovat.\n       máte vždy plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete nám pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení vypnuté a pokud se ho rozhodnete zapnout, budou data nejprve anonymizována a budete mít možnost vybrat, které věci sdílet. Nejnovější přijaté hlášení na naší straně přepíše to předchozí. Pokud chcete odstranit veškerá doposud od vás obdržená data, stačí zrušit zaškrtnutí všech kolonek a odeslat (tímto prázdné) hlášení.",
    "Send new report now" : "Odeslat nový přehled hned",
    "Send usage survey monthly" : "Odesílat přehled o používání každý měsíc",
    "Data to send" : "Data k odeslání",
    "Last report sent on: %s" : "Poslední hlášení odesláno: %s",
    "Last report" : "Poslední přehled"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
